@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::Extras::Money;
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 use 5.10.1;
 
@@ -15,17 +15,19 @@ sub Cobalt_register {
   my ($self, $core) = splice @_, 0, 2;
 
   $self->{Cached} = {};
-  $core->plugin_register( $self, 'SERVER',
-    [
-      'public_cmd_currency',
-      'public_cmd_cc',
-      'public_cmd_money',
+  
+  register( $self, 'SERVER',
+    qw/
+      public_cmd_currency
+      public_cmd_cc
+      public_cmd_money
       
-      'currencyconv_rate_recv',
-      'currencyconv_expire_cache',
-    ],
+      currencyconv_rate_recv
+      currencyconv_expire_cache
+    /
   );
-  $core->log->info("Loaded: cc money currency");
+
+  logger->info("Loaded: cc money currency");
 
   $core->timer_set( 1200,
     {
@@ -40,7 +42,9 @@ sub Cobalt_register {
 
 sub Cobalt_unregister {
   my ($self, $core) = splice @_, 0, 2;
-  $core->log->info("Unloaded");
+  
+  logger->info("Unloaded");
+  
   return PLUGIN_EAT_NONE
 }
 
@@ -49,8 +53,10 @@ sub Bot_currencyconv_expire_cache {
   
   for my $fromto (keys %{ $self->{Cached} }) {
     my $delta = time - $self->{Cached}->{$fromto}->{TS};
+
     if ($delta >= 1200) {
-      $core->log->debug("expired cached: $fromto");
+      logger->debug("expired cached: $fromto");
+
       delete $self->{Cached}->{$fromto};
     }
   }
@@ -77,7 +83,7 @@ sub Bot_public_cmd_currency {
   my ($value, $from, undef, $to) = @$message;
   
   unless ($value && $from && $to) {
-    $core->send_event( 'message', $context, $channel,
+    broadcast( 'message', $context, $channel,
       "Syntax: !cc <value> <abbrev> TO <abbrev>"
     );
     return PLUGIN_EAT_ALL
@@ -87,14 +93,14 @@ sub Bot_public_cmd_currency {
   my $valid_abbrev = qr/^[a-zA-Z]{3}$/;
 
   unless ($value =~ $valid_val) {
-    $core->send_event( 'message', $context, $channel,
+    broadcast( 'message', $context, $channel,
       "$value is not a valid quantity."
     );  
     return PLUGIN_EAT_ALL
   }
   
   unless ($from =~ $valid_abbrev && $to =~ $valid_abbrev) {
-    $core->send_event( 'message', $context, $channel,
+    broadcast( 'message', $context, $channel,
       "Currency codes must be three-letter abbreviations."
     );
     return PLUGIN_EAT_ALL
@@ -118,11 +124,11 @@ sub Bot_currencyconv_rate_recv {
   
   unless ($response->is_success) {
     if ($response->code == 500) {
-      $core->send_event( 'message', $context, $channel,
+      broadcast( 'message', $context, $channel,
         "Received error 500; is your currency code valid?"
       );
     } else {
-      $core->send_event( 'message', $context, $channel,
+      broadcast( 'message', $context, $channel,
         "HTTP failed: ".$response->code
       );
     }
@@ -136,7 +142,7 @@ sub Bot_currencyconv_rate_recv {
     $rate = $1||1;
     $converted = $value * $rate ;
   } else {
-    $core->send_event( 'message', $context, $channel,
+    broadcast( 'message', $context, $channel,
       "Failed to retrieve currency conversion ($from -> $to)"
     );
     return PLUGIN_EAT_ALL
@@ -148,7 +154,7 @@ sub Bot_currencyconv_rate_recv {
     TS   => time,
   };
   
-  $core->send_event( 'message', $context, $channel,
+  broadcast( 'message', $context, $channel,
     "$value $from == $converted $to"
   );
   
@@ -164,9 +170,11 @@ sub _request_conversion_rate {
   if ($self->{Cached}->{$cachekey}) {
     my $cachedrate = $self->{Cached}->{$cachekey}->{Rate};
     my $converted = $value * $cachedrate;
+
     broadcast( 'message', $context, $channel,
       "$value $from == $converted $to"
     );
+
     return 1
   }
 
@@ -176,6 +184,7 @@ sub _request_conversion_rate {
   
   if ( core()->Provided->{www_request} ) {
     my $req = HTTP::Request->new( 'GET', $uri ) || return undef;
+
     broadcast( 'www_request',
       $req,
       'currencyconv_rate_recv',
